AiMessage class

Annotations

Constructors

AiMessage(AiRole role, String content)
const
AiMessage.assistant(String content)
const
AiMessage.user(String content)
const

Properties

content String
final
hashCode int
The hash code for this object.
no setterinherited
role AiRole
final
roleName String
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited