CfOnStringExt extension

on

Methods

cf<T>(Config<ConfigRef> config, [Map args = const {}]) → T?

Available on String, provided by the CfOnStringExt extension

Resolves this string against config, returning the substituted value cast to T (or null if the result is not of that type).