AutoTranslationController<TRemoteDatabaseInterface extends DatabaseInterface, TCachedDatabaseInterface extends DatabaseInterface, TTranslationInterface extends TranslatorInterface<Object> > class
Constructors
- AutoTranslationController({bool autoTranslate = kDebugMode, required TRemoteDatabaseInterface? remoteDatabaseBroker, TCachedDatabaseInterface? persistentDatabaseBroker, TTranslationInterface? translationBroker, String cacheKey = 'locale', String translationPath = 'translations'})
Properties
- autoTranslate → bool
-
final
- cacheKey → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- locale → Locale?
-
no setter
-
pCache
→ GenericPod<
TTranslationMap> -
no setter
- persistentDatabaseBroker → TCachedDatabaseInterface?
-
final
-
pLocale
→ GenericPod<
Locale> -
no setter
- remoteDatabaseBroker → TRemoteDatabaseInterface?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- translationBroker → TTranslationInterface?
-
final
- translationPath → String
-
final
Methods
-
init(
) → Future< void> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setLocale(
Locale? locale) → Future< void> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited